@@ -275,9 +275,34 @@ import json
 #         print(e)
 #         print(profile)
 #         break
-
-f = open("data_formated.json")
+import sys
+f = open("/Users/mac/Desktop/data_formated.json")
 data = json.load(f)
 f.close()
-with open('data2_formated.json', 'w') as f:
-    json.dump(data[:250000], f, indent=4, default=str, ensure_ascii=False)
+# with open('/Users/mac/Desktop/data_formated_500000.json', 'w') as f:
+#     json.dump(data[:500000], f, indent=4, default=str, ensure_ascii=False)
+
+import uuid
+# Define the maximum size for each DynamoDB record in bytes (400KB)
+MAX_RECORD_SIZE = 400000
+my_list = data[:50000]
+# Split the list of dictionaries into multiple smaller ones
+partition_key = str(uuid.uuid4())  # Generate a random partition key
+records = []
+current_record = {'partition_key': partition_key}
+group_records = []
+for idx, my_dict in enumerate(my_list):
+    current_group_size = sys.getsizeof(group_records)
+    if current_group_size < MAX_RECORD_SIZE:
+        group_records.append(my_dict)
+    else:
+        records.append(group_records)
+        group_records = [my_dict]
+    
+    if idx == (len(my_list) - 1) and group_records:
+        records.append(group_records)
+total = 0
+for i, record in enumerate(records):
+    total += len(record)
+    print(f"Record {i+1} Length:{len(record)}")
+print(f'Total: {total}')
