@@ -7,8 +7,11 @@ def delete_file(path):
 
 
 def output_file_path():
-    return f'{tera_etl.root}/tera_etl/output'
+    dir_path = f'{tera_etl.root}/tera_etl/output'
+    if not os.path.exists(dir_path):
+        os.makedirs(dir_path)
+    return dir_path
 
 
 def test_data_folder():
-    return f'{tera_etl.root}/tests/data'
\ No newline at end of file
+    return f'{tera_etl.root}/tests/data'
